/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Felamimail **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:51+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Portuguese (Brazil) (http://www.transifex.com/tine20/tine20/language/pt_BR/)\nLanguage: pt_BR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Can not combine \"allow external\" and \"allow only members\""
: ""

, "Delete"
: "Apagar"

, "Reply"
: "Responder"

, "Reply To All"
: "Responder para Todos"

, "Forward"
: "Encaminhar"

, "Print Message"
: "Imprimir Mensagem"

, "Print Preview"
: "Impressão Prévia"

, "Add New Account"
: ""

, "Permissions"
: ""

, "Rules"
: ""

, "Vacation, Vacations"
: [
  "Férias"
 ,"Férias"

]
, "Account, Accounts"
: [
  "Conta"
 ,"Contas"

]
, "Account Name"
: "Nome da Conta"

, "Type"
: ""

, "Migration Approved"
: ""

, "Approve Migration"
: ""

, "Do you want to approve the migration of this account?"
: ""

, "User"
: ""

, "User Email"
: "Email do Usuário"

, "User Name (From)"
: "Nome do Usuário (De)"

, "Organization"
: "Organização"

, "Signature position"
: "Posição da Assinatura"

, "Above the quote"
: "Acima da quota"

, "Below the quote"
: "Abaixo da quota"

, "IMAP"
: "IMAP"

, "Host"
: "Hospedeiro"

, "Port (Default: 143 / SSL: 993)"
: "Porta (Padrão: 143 / SSL: 993)"

, "Secure Connection"
: "Conexão Segura"

, "None"
: "Nenhum"

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Username"
: "Nome do Usuário"

, "Password"
: "Senha"

, "Test IMAP Connection"
: ""

, "SMTP"
: "SMTP"

, "Port (Default: 25)"
: "Porta (Padrão: 25)"

, "Authentication"
: "Autenticação"

, "Login"
: "Entrada"

, "Plain"
: "Plano"

, "Username (optional)"
: "Nome do usuário (opcional)"

, "Password (optional)"
: "Senha (opcional)"

, "Test SMTP Connection"
: ""

, "Sieve"
: "Filtrar"

, "Port (Default: 2000)"
: "Porta (Padrão: 2000)"

, "Notification Email"
: ""

, "Auto-move notifications"
: ""

, "Auto-move notifications folder"
: ""

, "Other Settings"
: "Outros Parâmetros"

, "Sent Folder Name"
: "Nome da Pasta de Enviados"

, "Trash Folder Name"
: "Nome da Pasta de Lixo"

, "Drafts Folder Name"
: "Nome da Pasta de Rascunhos"

, "Templates Folder Name"
: "Nome da Pasta de Modelos"

, "Display Format"
: "Formato de Exibição"

, "HTML"
: "HTML"

, "Plain Text"
: "Texto Simples"

, "Depending on content type (experimental)"
: "Dependendo do tipo de conteúdo (experimental)"

, "Compose Format"
: ""

, "Preserve Format"
: ""

, "No"
: ""

, "Yes"
: ""

, "Reply-To Email"
: ""

, "It is not possible to convert accounts because the config option EMAIL_USER_ID_IN_XPROPS is disabled."
: ""

, "Migration has not been approved."
: ""

, "It is not possible to convert the account to this type."
: ""

, "System accounts cannot be created manually."
: ""

, "Mailinglist accounts cannot be created manually."
: ""

, "Account type change not possible"
: ""

, "E-Mail account needs a password"
: ""

, "Use"
: ""

, "The grant use the shared email account"
: ""

, "Edit"
: ""

, "The grant edit the shared email account"
: ""

, "Send Mails"
: ""

, "The grant to send mails via the email account"
: ""

, "Warning"
: ""

, "Server connection failed. Do you still want to save this setting and exit?"
: ""

, "Connection succeed"
: ""

, "Connecting to {0} server..."
: ""

, "Connection failed"
: ""

, "{server} Connection Status"
: ""

, "Save Message as"
: ""

, "File (in Filemanager) ..."
: ""

, "Attachment (of Record)"
: ""

, "Download"
: ""

, "{messageCount, plural, one {Message was saved} other {# messages where saved}}"
: ""

, "Success"
: ""

, "Error"
: ""

, "Save Messages as Attachment"
: ""

, "No Messages found."
: ""

, "It is SPAM"
: ""

, "It is not SPAM"
: ""

, "Compose"
: "Escrever"

, "Toggle highlighting"
: "Alternar destaque"

, "Mark read/unread"
: "Marcar como lida/não lida"

, "Move"
: ""

, "Copy"
: ""

, "Import Messages"
: ""

, "Add Account"
: "Adicionar Conta"

, "No target folder selected"
: ""

, "You need to select a target folder for the messages."
: ""

, "Wrong File Type"
: ""

, "Files of type eml allowed only."
: ""

, "Importing Messages..."
: ""

, "Id"
: "Id"

, "Attachments"
: "Anexos"

, "Flags"
: "Margadores"

, "Subject"
: "Assunto"

, "From (Email)"
: "De (email)"

, "From (Name)"
: "De (Nome)"

, "Sender"
: "Remetente"

, "To"
: "Para"

, "Sent"
: "Enviado"

, "Received"
: "Recebido"

, "Folder, Folders"
: [
  "Pasta"
 ,"Pastas"

]
, "Size"
: "Tamanho"

, "Answered"
: "Respondido"

, "Forwarded"
: "Encaminhado"

, "This message might be SPAM"
: ""

, "Tine20"
: ""

, "Encrypted Message"
: ""

, "Filed as:"
: ""

, "Select Message File Location"
: ""

, "Filing Messages"
: ""

, "Error Filing Message"
: ""

, "Could not file message."
: ""

, "Send Reading Confirmation"
: "Enviar Confirmação de Leitura"

, "Do you want to send a reading confirmation message?"
: "Você quer enviar a confirmação de leitura da mensagem ?"

, "Empty Folder"
: "Pasta Vazia"

, "Add Folder"
: "Adicionar Pasta"

, "New {0}"
: "Novo {0}"

, "Please enter the name of the new {0}:"
: "Favor informar o nome do novo {0}:"

, "No {0} added"
: "Nenhum {0} adicionado"

, "You have to supply a {0} name!"
: "Você deve fornecer o {0} nome!"

, "Please wait"
: "Favor aguardar"

, "Creating {0}..."
: "Criando {0}..."

, "Edit Account"
: "Editar Conta"

, "Edit Vacation Message"
: "Editar Mensagem de Férias"

, "Edit Filter Rules"
: "Editar Regras de Filtro"

, "Notifications"
: ""

, "Mark Folder as read"
: "Marcar Pasta como leitura"

, "Update Folder List"
: "Atualizar Lista de Pastas"

, "Message not available."
: "Mensagem não disponível."

, "Cancel"
: "Cancelar"

, "Ok"
: "Ok"

, "Folders of account {0}"
: "Pastas da conta {0}"

, "Folders of all accounts"
: "Pastas de todas as contas"

, "Compose email"
: "Escrever email"

, "CC"
: ""

, "BCC"
: ""

, "Mass Mailing"
: ""

, "Open in Felamimail"
: ""

, "From"
: "De"

, "Add"
: "Adicionar"

, "Add contact to addressbook"
: "Adicionar contato ao catálogo de endereços"

, "Date"
: "Data"

, "Show or hide header information"
: "Exibir ou ocultar o cabeçalho da informação"

, "{locationCount, plural, one {This message is filed at the following location} other {This message is filed at the following locations}}: {locationsHtml}"
: ""

, "Open"
: ""

, "Save As"
: ""

, "{attachmentCount, plural, one {Attachment was saved} other {# Attachments where saved}}"
: ""

, "Save as Record Attachment"
: ""

, "This message is probably SPAM. Please help to train your anti-SPAM system with a decision: \"Yes, it is SPAM\" or \"No, it is not\""
: ""

, "Confirm SPAM Suspicion"
: ""

, "Yes, it is SPAM"
: ""

, "No, it is not"
: ""

, "(new message)"
: "(nova mensagem)"

, "Select recipients for \"{0}\""
: "Selecionar destinatários para \"{0}\""

, "Signatures"
: ""

, "Name"
: ""

, "Is Default"
: ""

, "Add Signature"
: ""

, "Edit Signature"
: ""

, "Delete Signature"
: ""

, "Recipient filter"
: "Filtro do destinatário"

, "All recipients"
: "Todos os destinatários"

, "\"{0}\" recipients"
: "\"{0}\" destinatários"

, "Attachment"
: ""

, "Filemanager (Download link)"
: ""

, "Filemanager (Download link, password)"
: ""

, "Filemanager (Systemlink)"
: ""

, "Attachment Type"
: ""

, "Click icon to change"
: ""

, "name"
: ""

, "size"
: ""

, "type"
: ""

, "Vacation Message for {0}"
: "Mensagem de Férias para {0}"

, "Notification for {0}"
: ""

, "Move up"
: "Mover-se"

, "Move down"
: "Mover para baixo"

, "Enable"
: "Permitir"

, "Disable"
: "Desativar"

, "ID"
: "ID"

, "Conditions"
: "Condições"

, "Action"
: "Ação"

, "Keep a copy"
: ""

, "is greater than"
: "é maior que"

, "is less than"
: "é menor que"

, "Header \"{0}\" contains \"{1}\""
: "Cabeçalho \"{0}\" contém \"{1}\""

, "Header \"{0}\" matches \"{1}\""
: "Cabeçalho \"{0}\" matches \"{1}\""

, "Sieve Filter Rules"
: "Regras para aplicar o filtro"

, "Sieve Filter Rules for {0}"
: "Regras para aplicar o Filtro por {0}"

, "From (Email and Name)"
: "De (Email e Nome)"

, "To (Email)"
: "Para (Email)"

, "To (Email CC)"
: ""

, "Header contains"
: "Cabeçalho contém"

, "Header name"
: "Nome do cabeçalho"

, "Header value"
: "Valor do cabeçalho"

, "Header regex"
: "Valor do cabeçalho"

, "Edit Filter Rule"
: "Editar Regra de Filtro"

, "Apply filter if"
: ""

, "all conditions match"
: ""

, "any condition matches"
: ""

, "Do this action:"
: "Faça esta ação:"

, "Move mail to folder"
: "Mover correio para a pasta"

, "Redirect mail to address"
: "Redirecionar correio para o endereço"

, "Reject mail with this text"
: "Rejeitar correio com este texto"

, "Discard mail"
: "Descartar correio"

, "Auto-Reply mail with this text"
: ""

, "Keep mail"
: "Guardar correio"

, "General"
: "Geral"

, "Advanced"
: "Avançado"

, "Only send all X days to the same sender"
: "Enviar somente todas X dias para o mesmo remetente"

, "Incoming mails will be answered with this text:"
: "Correios de entrada serão respondidos com este texto:"

, "Status"
: "Situação"

, "I am available (vacation message disabled)"
: "Estou disponível (mensagem de férias desativada)"

, "I am not available (vacation message enabled)"
: "Não estou disponível (mensagem de férias habilitada)"

, "Start Date"
: "Data de Início"

, "Set vacation start date ..."
: "Marcar data de início das férias ..."

, "End Date"
: "Data Final"

, "Set vacation end date ..."
: "Marcar data final das férias ..."

, "Representative #1"
: "Representante #1"

, "Choose first Representative ..."
: "Escolher o primeiro Representante ..."

, "Representative #2"
: "Representante #2"

, "Choose second Representative ..."
: "Escolher o segundo Representante ..."

, "Message Template"
: "Modelo de Mensagem"

, "Choose Template ..."
: "Escolher Modelo ..."

, "Mailvelope decryption Error [{0}]"
: ""

, "To decrypt this message please install {0} with API support enabled"
: ""

, "PGP encrypted Message"
: ""

, "GENDER_Message"
: ""

, "Message, Messages"
: [
  "Mensagem"
 ,"Mensagens"

]
, "Subject/From"
: "Assunto/De"

, "Cc"
: "Cc"

, "Bcc"
: "Cco"

, "INBOX"
: "Caixa de Entrada"

, "Drafts"
: "Rascunhos"

, "Templates"
: "Modelos"

, "Junk"
: "Lixo"

, "Trash"
: "Lixeira"

, "GENDER_Folder"
: ""

, "record list, record lists"
: [
  "lista de registro"
 ,"listas de registros"

]
, "Rule, Rules"
: [
  "Regra"
 ,"Regras"

]
, "Flag, Flags"
: [
  "Marcador"
 ,"Marcadores"

]
, "Flag list, Flag lists"
: [
  "Lista de marcadores"
 ,"Listas de marcadores"

]
, "Total Messages:"
: "Total de Mensagens:"

, "Unread Messages:"
: "Mensagens não Lidas:"

, "Name on Server:"
: "Nome no Servidor:"

, "Last update:"
: "Última atualização:"

, "Fetching messages... ({0} done)"
: ""

, "{0} unread message, {0} unread messages"
: [
  "mensagem não lida"
 ,"mensagens não lidas"

]
, "New Mail"
: "Novo Correio"

, "Email"
: "Email"

, "Active Vacation Message"
: "Ativar Mensagem de Férias"

, "Email account \"{0}\" has an active vacation message."
: "Conta de Email \"{0}\" tem mensagem de férias ativa."

, "Poll URL: {0}"
: ""

, "{0} as default mailer"
: ""

, "New mails"
: "Novos correios"

, "You got {0} new mail(s) in folder {1} ({2})."
: "Você tem {0} novo(s) correio(s) na pasta {1} ({2})."

, "IMAP Credentials for {0}"
: "Credenciais de IMAP para {0}"

, "Credentials"
: "Credenciais"

, "IMAP Error"
: "Erro IMAP"

, "No connection to IMAP server."
: "Sem conexão para o servidor IMAP."

, "IMAP Credentials Error"
: "Erro de Credenciais no IMAP"

, "Your email credentials are wrong. Please contact your administrator"
: "Suas credenciais de email estão erradas. Favor contactar seu administrador"

, "One of your folders was deleted or renamed by another client. Please update the folder list of this account."
: "Uma das suas pastas foi apagada ou renomeada por outro cliente. Favor atualize a lista de pastas desta conta."

, "SMTP Error"
: "Erro SMTP"

, "No connection to SMTP server."
: "Nenhuma conexão com o servidor SMTP."

, "Sieve Error"
: "Erro "

, "No connection to Sieve server."
: "Nenhuma conexão ao servidor de filtragem"

, "Save Sieve Script Error"
: "Erro ao salvar o script de filtragem"

, "Could not save script on Sieve server."
: "O script não pode ser salvo no servidor de filtragem"

, "Add as \"To\""
: "Adicionar como \"Para\""

, "Add as \"Cc\""
: "Adicionar como \"Cc\""

, "Add as \"Bcc\""
: "Adicionar como \"Cco\""

, "Remove from recipients"
: "Remover dos beneficiários"

, "Loading Mail Addresses"
: "Carregando Endereço de Correio"

, "Click here to set To/CC/BCC."
: "Clique aqui para assinalar Para/CC/CCO."

, "To:"
: "Para"

, "Cc:"
: "Cc"

, "Bcc:"
: "Cco"

, "Remove"
: "Remover"

, "Send"
: "Enviar"

, "Search Recipients"
: "Procurar destinatários"

, "Save As Draft"
: "Salvar como Rascunho"

, "Save As Template"
: "Salvar como Modelo"

, "Reading Confirmation"
: "Lendo Confirmação"

, "Activate this toggle button to receive a reading confirmation."
: "Ativar o botão alternativo para receber uma confirmação de leitura"

, "Encrypt Email"
: ""

, "Encrypt email using Mailvelope"
: ""

, "Activate this toggle button to send the mail as separate mail to each recipient."
: ""

, "Click to search for and add recipients from the Addressbook."
: "Clique para pesquisar e adicionar destinatários da lista de \" \"endereços"

, "Encrypted Content"
: ""

, "Discard this Draft?"
: ""

, "Do you want to discard the current draft?"
: ""

, "Fwd:"
: "Fwd:"

, "{0} Message"
: "{0} Messagem"

, "Failed"
: "Falhou"

, "{0} account setting empty."
: "{0} parâmetros da conta vazios."

, "Files are still uploading."
: "Arquivos ainda sendo carregados."

, "{locationCount, plural, one {This message will be filed at the following location} other {This message will be filed at the following locations}}: {locationsHtml}"
: ""

, "On {0}, {1} wrote"
: "No {0}, {1} escreveu"

, "Original message"
: "Mensagem original"

, "Compose email:"
: "Escrever email:"

, "Convert to formated text"
: ""

, "Body"
: "Corpo"

, "NOTE: This is mail will be sent as a mass mail, i.e. each recipient will get his or her own copy."
: ""

, "Add email address here for reply-to"
: ""

, "Signature, Signatures"
: [
  ""
 ,""

]
, "Some attachments are of type \"systemlinks\" whereas some of the recipients (marked yellow), couldn't be validated to be accounts on this installation. Only recipients with an active account will be able to open those attachments."
: ""

, "Do you really want to send?"
: ""

, "Empty subject"
: "Falta o assunto"

, "Do you really want to send a message with an empty subject?"
: "Você quer realmente enviar a mensagem sem um assunto?"

, "No recipients set."
: "Nenhum destinatário selecionado."

, "Mass mailing is not allowed for CC or BCC recipients. Please remove them."
: ""

, "Cannot encrypt message. Public keys for the following recipients are missing: {0}"
: ""

, "All inboxes"
: "Todas as caixas de entrada"

, "Default Email Account"
: "Conta de Email Padrão"

, "The default email account to use when sending mails."
: "A conta de email padrão a ser usada quando enviar correio."

, "Mark Email Automatically As Read"
: ""

, "Is email marked as read automatically or by user action"
: ""

, "Email Update Interval"
: "Intervalo de Atualização de Email"

, "How often should Felamimail check for new Emails (in minutes)."
: "Com que frequência Felamimail deve verificar por novas mensagens (em minutos)."

, "Use for mailto links"
: ""

, "Use Felamimail in mailto links, otherwise use the default desktop client."
: ""

, "Use for NOTES"
: "Usar para NOTAS"

, "Save Note default Value."
: "Salvar Valor padrão para Nota."

, "Confirm Delete"
: "Confirmar Apagar"

, "Show confirmation dialog when deleting mails."
: "Exibir diálogo de confirmação quando apagar correios."

, ".eml file Attachment in forwarded mails"
: ""

, "Attach an .eml file to a forwarded mail. Otherwise all attachments separate"
: ""

, "Default Font"
: ""

, "Setting the default font in the E-Mail app"
: ""

, "Mail Type"
: ""

, "Possible mail types."
: ""

, "Additional Personal External Account"
: ""

, "Shared System Account"
: ""

, "Additional Personal System Account"
: ""

, "Default Personal System Account"
: ""

, "Mailinglist"
: ""

, "Mailinglist Reject Reason"
: ""

, "Your email has been rejected"
: ""

, "Vacation Templates Node ID"
: ""

, "Email Notification Templates Node ID"
: ""

, "Custom Vacation Message"
: "Mensagem de Férias Personalizada"

, "User is allowed to set custom vacation message for system account"
: "Usuário tem permissão para customizar mensagem de férias para conta do sistema"

, "Cache email body"
: "Ocultar conteúdo do email"

, "Should the email body be cached (recommended for slow IMAP server connections)"
: "Caso o corpo do email seja armazenado em cache (recomendado para servidor IMAP lento)"

, "Delete Archived Mail"
: ""

, "Prevent copying mails in the same account"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Felamimail Application."
: ""

, "Account Migration"
: ""

, "Shows context menu for system accounts to approve migration"
: ""

, "Move notifications"
: ""

, "Move notifications to a subfolder via sieve"
: ""

, "Auto-Save Drafts"
: ""

, "Save drafts automatically while editing an email"
: ""

, "Only password download link"
: ""

, "Allow only password download link"
: ""

, "Tine 2.0 Flag"
: ""

, "Add a Tine 2.0 flag to sent messages"
: ""

, "Show Reply-To"
: ""

, "Show Reply-To field in message compose dialog"
: ""

, "Auto-Create Folders"
: ""

, "Create template, trash, sent, draft and junks folders for system accounts"
: ""

, "Enable Spam Suspicion Strategy"
: ""

, "SEnable pam Suspicion Strategy"
: ""

, "Spam Suspicion Strategy"
: ""

, "Spam Suspicion Strategy Config"
: ""

, "Spam User Processing Pipeline"
: ""

, "Confirm SPAM Suspicion Message"
: ""

, "Message for users when they press the info button in a SPAM suspicion toolbar."
: ""

, "Filter E-Mail URIs"
: ""

, "Should the email body uris be filtered. Only anchors with URIs are allowed if this is turned on"
: ""

, "System Account Folder Defaults"
: ""

, "Paths of the special folders (like Sent, Trash, ...)"
: ""

, "Allow self signed TLS cert for IMAP connection"
: ""

, "Sieve Redirect Only Internal"
: ""

, "Allow only sieve redirect rules to internal (primary/secondary) email addresses"
: ""

, "Sieve Notification Bounces Reporting Email"
: ""

, "URL icon path for own domain"
: ""

, "Used to mark messages from configured primary and secondary domains"
: ""

, "URL icon path for other domains"
: ""

, "Used to mark messages from all other domains"
: ""

, "Other domain regex for FLAG_ICON_OTHER_DOMAIN"
: ""

, "shared / adb_list accounts need to have a password set"
: ""

, "Is default"
: ""

, "Email Account, Email Accounts"
: [
  ""
 ,""

]
, "IMAP Host"
: ""

, "IMAP Port"
: ""

, "IMAP SSL"
: ""

, "Sent Folder"
: ""

, "Trash Folder"
: ""

, "Drafts Folder"
: ""

, "Templates Folder"
: ""

, "Reply-To"
: ""

, "E-Mail"
: ""

, "Signature Position"
: ""

, "SMTP Host"
: ""

, "SMTP Port"
: ""

, "SMTP SSL"
: ""

, "SMTP Authentication"
: ""

, "Sieve Host"
: ""

, "Sieve Port"
: ""

, "Sieve SSL"
: ""

, "Reading Confirmation:"
: "Lendo Confirmação:"

, "Your message:"
: "Sua mensagem"

, "Received on"
: "Recebido em"

, "Was read by:"
: "Foi lido por:"

, "on"
: "em"

, "Message File Location, Message File Locations"
: [
  ""
 ,""

]
, "Message File Locations"
: ""

, "Message ID Hash"
: ""

, "Message ID"
: ""

, "Model"
: ""

, "Record ID"
: ""

, "Record Title"
: ""

, "Node ID"
: ""

, "Message File Suggestion, Message File Suggestions"
: [
  ""
 ,""

]
, "Message File Suggestions"
: ""

, "Out of Office reply from %1$s"
: "Fora do escritório responder de %1$s"

, "It is not allowed to redirect emails to self! Please change the recipient."
: ""

, "Redirects to external email domains are not allowed."
: ""

, "You have new mail from "
: ""

, "shared / adb_list accounts need to have an email set"
: ""

, "userInternal accounts are only allowed with Tinebase_Config::EMAIL_USER_ID_IN_XPROPS"
: ""

, "userInternal accounts need to have an email set"
: ""

, "userInternal accounts need to have an user_id set"
: ""

, "Please choose a new email address for userInternal accounts"
: ""

, "system account for user does not exist"
: ""

, "Account type cannot be changed from {0} to {1}"
: ""

, "Config EMAIL_USER_ID_IN_XPROPS is not enabled! Please check if your email user backend supports it and run CLI method Tinebase.emailUserIdInXprops"
: ""

, "Migration of this account has not been approved!"
: ""

, "Could not find email user xprops!"
: ""

, "Internal user accounts need a valid user"
: ""

, "System account of user is missing"
: ""

, "Bad recipient address syntax"
: ""

, "Recipient address rejected"
: ""

, "Original message not found, email was moved or deleted"
: ""

, "Invalid address format"
: ""

, "Error: %s"
: ""

, "Could not send message"
: ""

, "My Mail Download Links"
: ""

, "Seen"
: "Visto"

, "Deleted"
: "Apagado"

, "Draft"
: "Rascunho"

, "Flagged"
: "Marcado"

, "It is not allowed to copy e-mails in the same account."
: ""

, "Folder with name {0} already exists!"
: ""

, "Failure on create folder"
: ""

, "All inboxes of my email accounts"
: "Todas as caixas de entrada de minhas contas de email"

, "All unread mail"
: "Todos os emails não lidos"

, "All unread mail of my email accounts"
: "Todos os emails não lidos das minhas contas de email"

, "All highlighted mail"
: "Todos os correios importantes"

, "All highlighted mail of my email accounts"
: "Todos os correios importantes das minhas contas de email"

, "All drafts"
: "Todos os rascunhos"

, "All mails with the draft flag"
: "Todos os correios marcados como rascunho"

, "IMAP Hostname missing"
: ""

, "IMAP Credentials missing"
: ""

, "SMTP Hostname missing"
: ""

, "SMTP Credentials missing"
: ""

, "manage email accounts"
: "gerenciar contas de email"

, "Edit and delete email accounts"
: "Editar e apagar contas de email"

, "Add email accounts"
: "Adicionar contas de email"

, "Create new email accounts"
: "Criar novas contas de email"

, "Vacation"
: "Férias"

, "Account"
: "Conta"

, "Folder"
: "Pasta"

, "Message"
: "Mensagem"

, "record list"
: "lista de registro"

, "Rule"
: "Regra"

, "Flag"
: "Marcador"

, "Flag list"
: "Lista de marcadores"

, "{0} unread message"
: "mensagem não lida"

, "Signature"
: ""

, "Email Account"
: ""

, "Message File Location"
: ""

, "Message File Suggestion"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
